@@ -9,6 +9,8 @@ else
     --env IS_CONTAINER=TRUE \
     --volume "${PWD}:/go/src/github.com/openshift/machine-api-operator:z" \
     --workdir /go/src/github.com/openshift/machine-api-operator \
+    --env GO111MODULE="$GO111MODULE" \
+    --env GOFLAGS="$GOFLAGS" \
     openshift/origin-release:golang-1.12 \
     ./hack/go-fmt.sh "${@}"
 fi
